@@ -61,14 +61,8 @@ _DEFAULT_CONFIG = {
         "port": 48008,
         "log_dir": (os.environ.get("XDG_CACHE_HOME") or (os.environ["HOME"] + "/.cache"))
         + "/covalent",
-    },
-    "executors": {
-        "local": {
-            "log_stdout": "stdout.log",
-            "log_stderr": "stderr.log",
-            "cache_dir": "/tmp/covalent",
-        },
-        # Add entries for custom executors here
+        "dispatch_db": (os.environ.get("XDG_CACHE_HOME") or (os.environ["HOME"] + "/.cache"))
+        + "/covalent/dispatch_db.sqlite",
     },
 }
 
